"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.envCommand = void 0;
exports.getOwnVersion = getOwnVersion;
var _commander = require("commander");
var _options = require("../options");
var _path = _interopRequireDefault(require("path"));
var _logger = require("../../utils/logger");
var _utils = require("../../utils");
var _loadConfig = require("../../playwright/loadConfig");
const logger = new _logger.Logger({
  verbose: true
});
const envCommand = exports.envCommand = new _commander.Command('env').description('Prints environment info').addOption(_options.configOption).action(opts => {
  logger.log(`Playwright-bdd environment info:\n`);
  logger.log(`platform: ${process.platform}`);
  logger.log(`node: ${process.version}`);
  showPackageVersion('playwright-bdd');
  showPackageVersion('@playwright/test');
  showPackageVersion('@cucumber/cucumber');
  showPlaywrightConfigPath(opts.config);
});
function showPackageVersion(packageName) {
  const version = packageName === 'playwright-bdd' ? getOwnVersion() : (0, _utils.getPackageVersion)(packageName);
  logger.log(`${packageName}: v${version}`);
}
/**
 * Getting own version by relative path instead of using getPackageVersion(),
 * to aneble using directly from /dist in tests.
 */
function getOwnVersion() {
  return '6.1.1';
}
function showPlaywrightConfigPath(cliConfigPath) {
  const resolvedConfigFile = (0, _loadConfig.resolveConfigFile)(cliConfigPath);
  const relPath = _path.default.relative(process.cwd(), resolvedConfigFile);
  logger.log(`Playwright config file: ${relPath}`);
}