"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.exportCommand = void 0;
var _path = _interopRequireDefault(require("path"));
var _commander = require("commander");
var _options = require("../options");
var _loadConfig = require("../../playwright/loadConfig");
var _logger = require("../../utils/logger");
var _env = require("../../config/env");
var _test = require("./test");
var _gen = require("../../gen");
const logger = new _logger.Logger({
  verbose: true
});
const exportCommand = exports.exportCommand = new _commander.Command('export').description('Prints step definitions').addOption(_options.configOption).option('--unused-steps', 'Output only unused steps').action(async opts => {
  const {
    resolvedConfigFile
  } = await (0, _loadConfig.loadConfig)(opts.config);
  logger.log(`Using config: ${_path.default.relative(process.cwd(), resolvedConfigFile)}`);
  const configs = Object.values((0, _env.getEnvConfigs)());
  (0, _test.assertConfigsCount)(configs);
  if (opts.unusedSteps) {
    await showUnusedStepsForConfigs(configs);
  } else {
    await showStepsForConfigs(configs);
  }
});
async function showStepsForConfigs(configs) {
  // here we don't need workers (as in test command) because if some step files
  // are already in node cache, we collected them.
  const steps = new Set();
  const tasks = configs.map(async config => {
    const stepDefinitions = await new _gen.TestFilesGenerator(config).extractSteps();
    stepDefinitions.forEach(s => steps.add(`* ${getStepText(s)}`));
  });
  await Promise.all(tasks);
  logger.log(`List of all steps (${steps.size}):`);
  steps.forEach(stepText => logger.log(stepText));
}
async function showUnusedStepsForConfigs(configs) {
  const steps = new Set();
  const tasks = configs.map(async config => {
    const stepDefinitions = await new _gen.TestFilesGenerator(config).extractUnusedSteps();
    stepDefinitions.forEach(s => steps.add(`* ${getStepText(s)}`));
  });
  await Promise.all(tasks);
  logger.log(`List of unused steps (${steps.size}):`);
  steps.forEach(stepText => logger.log(stepText));
}
function getStepText({
  pattern,
  keyword
}) {
  // for Unknown return When as it looks the most suitable
  const keywordText = keyword === 'Unknown' ? 'When' : keyword;
  const patternText = typeof pattern === 'string' ? pattern : pattern.source;
  return `${keywordText} ${patternText}`;
}