"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.assertConfigsCount = assertConfigsCount;
exports.testCommand = void 0;
var _worker_threads = require("worker_threads");
var _events = require("events");
var _path = _interopRequireDefault(require("path"));
var _commander = require("commander");
var _gen = require("../../gen");
var _loadConfig = require("../../playwright/loadConfig");
var _env = require("../../config/env");
var _config = require("../../config");
var _options = require("../options");
var _exit = require("../../utils/exit");
const GEN_WORKER_PATH = _path.default.resolve(__dirname, '..', 'worker.js');
const testCommand = exports.testCommand = new _commander.Command('test').description('Generate Playwright test files from Gherkin documents').addOption(_options.configOption).option('--tags <expression>', `Tags expression to filter scenarios for generation`).option('--verbose', `Verbose mode (default: ${Boolean(_config.defaults.verbose)})`).action(async opts => {
  await (0, _loadConfig.loadConfig)(opts.config);
  const configs = readConfigsFromEnv();
  mergeCliOptions(configs, opts);
  await generateFilesForConfigs(configs);
});
function readConfigsFromEnv() {
  const configs = Object.values((0, _env.getEnvConfigs)());
  assertConfigsCount(configs);
  return configs;
}
function mergeCliOptions(configs, opts) {
  configs.forEach(config => {
    if ('tags' in opts) {
      config.tags = opts.tags;
    }
    if ('verbose' in opts) {
      config.verbose = Boolean(opts.verbose);
    }
  });
}
function assertConfigsCount(configs) {
  if (configs.length === 0) {
    (0, _exit.exit)(`No BDD configs found. Did you use defineBddConfig() in playwright.config.ts?`);
  }
}
async function generateFilesForConfigs(configs) {
  // run first config in main thread and other in workers (to have fresh require cache)
  // See: https://github.com/vitalets/playwright-bdd/issues/32
  const tasks = configs.map((config, index) => {
    return index === 0 ? new _gen.TestFilesGenerator(config).generate() : runInWorker(config);
  });
  return Promise.all(tasks);
}
async function runInWorker(config) {
  const worker = new _worker_threads.Worker(GEN_WORKER_PATH, {
    workerData: {
      config
    }
  });
  const [exitCode] = await (0, _events.once)(worker, 'exit');
  if (exitCode) {
    (0, _exit.exit)();
  }
}