"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPlaywrightConfigDir = getPlaywrightConfigDir;
var _path = _interopRequireDefault(require("path"));
var _loadConfig = require("../playwright/loadConfig");
var _options = require("../cli/options");
/**
 * Store playwright config dir in env to provide access to it in workers.
 * Important that in workers there is different process.argv, that's why we save it to env.
 * Config dir is needed to resolve all paths (features, step definitions).
 */

/**
 * Returns Playwright config dir considering cli --config option.
 */
function getPlaywrightConfigDir({
  resolveAndSave = false
} = {}) {
  let configDir = process.env.PLAYWRIGHT_BDD_CONFIG_DIR;
  if (!configDir) {
    if (resolveAndSave) {
      const cliConfigPath = (0, _options.getCliConfigPath)();
      const playwrightConfigFile = (0, _loadConfig.resolveConfigFile)(cliConfigPath);
      configDir = playwrightConfigFile ? _path.default.dirname(playwrightConfigFile) : process.cwd();
      process.env.PLAYWRIGHT_BDD_CONFIG_DIR = configDir;
    } else {
      throw new Error(`Something went wrong: PLAYWRIGHT_BDD_CONFIG_DIR is not set.`);
    }
  }
  return configDir;
}