"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getConfigFromEnv = getConfigFromEnv;
exports.getEnvConfigs = getEnvConfigs;
exports.saveConfigToEnv = saveConfigToEnv;
var _path = _interopRequireDefault(require("path"));
var _exit = require("../utils/exit");
/**
 * Storing configs in env var PLAYWRIGHT_BDD_CONFIGS as JSON-stringified values.
 * For passing configs to playwright workers and bddgen.
 */

function saveConfigToEnv(config) {
  const envConfigs = getEnvConfigs();
  const existingConfig = envConfigs[config.outputDir];
  if (existingConfig) {
    // Playwright config can be evaluated several times.
    // Throw error only if different calls of defineBddConfig() use the same outputDir.
    // See: https://github.com/vitalets/playwright-bdd/issues/39#issuecomment-1653805368
    if (!isSameConfigs(config, existingConfig)) {
      (0, _exit.exit)(`When using several calls of defineBddConfig()`, `please manually provide different "outputDir" option.`);
    }
    return;
  }
  envConfigs[config.outputDir] = config;
  saveEnvConfigs(envConfigs);
}
function getConfigFromEnv(outputDir) {
  const envConfigs = getEnvConfigs();
  outputDir = _path.default.resolve(outputDir);
  const config = envConfigs[outputDir];
  if (!config) {
    // exit(`Config not found for outputDir: "${outputDir}".`, `Available dirs: ${Object.keys(envConfigs).join('\n')}`);
    return {};
  }
  return config;
}
function getEnvConfigs() {
  return JSON.parse(process.env.PLAYWRIGHT_BDD_CONFIGS || '{}');
}
function saveEnvConfigs(envConfigs) {
  process.env.PLAYWRIGHT_BDD_CONFIGS = JSON.stringify(envConfigs);
}
function isSameConfigs(config1, config2) {
  return JSON.stringify(config1) === JSON.stringify(config2);
}