"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.defaults = void 0;
exports.defineBddConfig = defineBddConfig;
exports.extractCucumberConfig = extractCucumberConfig;
var _path = _interopRequireDefault(require("path"));
var _env = require("./env");
var _configDir = require("./configDir");
var _utils = require("../utils");
/**
 * BDD Config.
 */

const defaults = exports.defaults = {
  outputDir: '.features-gen',
  verbose: false,
  examplesTitleFormat: 'Example #<_index_>',
  publishQuiet: true,
  quotes: 'double'
};
function defineBddConfig(inputConfig) {
  const isMainProcess = !process.env.TEST_WORKER_INDEX;
  const configDir = (0, _configDir.getPlaywrightConfigDir)({
    resolveAndSave: isMainProcess
  });
  const config = getConfig(configDir, inputConfig);
  // In main process store config in env to be accessible by workers
  if (isMainProcess) {
    (0, _env.saveConfigToEnv)(config);
  }
  return config.outputDir;
}
function getConfig(configDir, inputConfig) {
  const config = Object.assign({}, defaults, inputConfig);
  const featuresRoot = config.featuresRoot ? _path.default.resolve(configDir, config.featuresRoot) : configDir;
  return {
    ...config,
    // important to resolve outputDir as it is used as unique key for input configs
    outputDir: _path.default.resolve(configDir, config.outputDir),
    importTestFrom: resolveImportTestFrom(configDir, config.importTestFrom),
    featuresRoot
  };
}
function extractCucumberConfig(config) {
  // todo: find more strict way to omit own config fields
  // see: https://bobbyhadz.com/blog/typescript-object-remove-property
  const omitProps = {
    outputDir: true,
    importTestFrom: true,
    verbose: true,
    skip: true,
    examplesTitleFormat: true,
    quotes: true,
    tags: true,
    featuresRoot: true,
    enrichReporterData: true
  };
  const keys = Object.keys(omitProps);
  const cucumberConfig = {
    ...config
  };
  keys.forEach(key => delete cucumberConfig[key]);
  stripPublishQuiet(cucumberConfig);
  return cucumberConfig;
}
function resolveImportTestFrom(configDir, importTestFrom) {
  if (importTestFrom) {
    const {
      file,
      varName
    } = typeof importTestFrom === 'string' ? {
      file: importTestFrom
    } : importTestFrom;
    return {
      file: _path.default.resolve(configDir, file),
      varName
    };
  }
}
function stripPublishQuiet(cucumberConfig) {
  const cucumberVersion = (0, _utils.getPackageVersion)('@cucumber/cucumber');
  // Playwright-bdd supports Cucumber from v9+
  // publishQuiet was deprecated in Cucumber 9.4.0.
  // See: https://github.com/cucumber/cucumber-js/pull/2311
  // Remove publishQuite from Cucumber config to hide deprecation warning.
  // See: https://github.com/vitalets/playwright-bdd/pull/47
  if (!/^9\.[0123]\./.test(cucumberVersion)) {
    delete cucumberConfig.publishQuiet;
  }
}