"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var messages = _interopRequireWildcard(require("@cucumber/messages"));
var _valueChecker = require("../valueChecker");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Groups Cucumber messages for easier access.
 * Based on Cucumber, with some changes due to strictNullChecks errors.
 * See: https://github.com/cucumber/cucumber-js/blob/main/src/formatter/helpers/event_data_collector.ts
 */

class EventDataCollector {
  gherkinDocumentMap = {};
  pickleMap = {};
  testCaseMap = {};
  testCaseAttemptDataMap = {};
  undefinedParameterTypes = [];
  constructor(eventBroadcaster) {
    eventBroadcaster.on('envelope', this.parseEnvelope.bind(this));
  }
  /**
     * @public
     */
  getGherkinDocument(uri) {
    return this.gherkinDocumentMap[uri];
  }
  /**
     * @public
     */
  getPickle(pickleId) {
    return this.pickleMap[pickleId];
  }
  getTestCaseAttempts() {
    return Object.keys(this.testCaseAttemptDataMap).map(testCaseStartedId => {
      return this.getTestCaseAttempt(testCaseStartedId);
    });
  }
  getTestCaseAttempt(testCaseStartedId) {
    const testCaseAttemptData = this.testCaseAttemptDataMap[testCaseStartedId];
    const testCase = this.testCaseMap[testCaseAttemptData.testCaseId];
    const pickle = this.pickleMap[testCase.pickleId];
    return {
      gherkinDocument: this.gherkinDocumentMap[pickle.uri],
      pickle,
      testCase,
      attempt: testCaseAttemptData.attempt,
      willBeRetried: testCaseAttemptData.willBeRetried,
      stepAttachments: testCaseAttemptData.stepAttachments,
      stepResults: testCaseAttemptData.stepResults,
      worstTestStepResult: testCaseAttemptData.worstTestStepResult
    };
  }
  parseEnvelope(envelope) {
    var _envelope$gherkinDocu;
    if ((0, _valueChecker.doesHaveValue)((_envelope$gherkinDocu = envelope.gherkinDocument) === null || _envelope$gherkinDocu === void 0 ? void 0 : _envelope$gherkinDocu.uri)) {
      this.gherkinDocumentMap[envelope.gherkinDocument.uri] = envelope.gherkinDocument;
    } else if ((0, _valueChecker.doesHaveValue)(envelope.pickle)) {
      this.pickleMap[envelope.pickle.id] = envelope.pickle;
    } else if ((0, _valueChecker.doesHaveValue)(envelope.undefinedParameterType)) {
      this.undefinedParameterTypes.push(envelope.undefinedParameterType);
    } else if ((0, _valueChecker.doesHaveValue)(envelope.testCase)) {
      this.testCaseMap[envelope.testCase.id] = envelope.testCase;
    } else if ((0, _valueChecker.doesHaveValue)(envelope.testCaseStarted)) {
      this.initTestCaseAttempt(envelope.testCaseStarted);
    } else if ((0, _valueChecker.doesHaveValue)(envelope.attachment)) {
      this.storeAttachment(envelope.attachment);
    } else if ((0, _valueChecker.doesHaveValue)(envelope.testStepFinished)) {
      this.storeTestStepResult(envelope.testStepFinished);
    } else if ((0, _valueChecker.doesHaveValue)(envelope.testCaseFinished)) {
      this.storeTestCaseResult(envelope.testCaseFinished);
    }
  }
  initTestCaseAttempt(testCaseStarted) {
    this.testCaseAttemptDataMap[testCaseStarted.id] = {
      attempt: testCaseStarted.attempt,
      willBeRetried: false,
      testCaseId: testCaseStarted.testCaseId,
      stepAttachments: {},
      stepResults: {},
      worstTestStepResult: {
        duration: {
          seconds: 0,
          nanos: 0
        },
        status: messages.TestStepResultStatus.UNKNOWN
      }
    };
  }
  storeAttachment(attachment) {
    const {
      testCaseStartedId,
      testStepId
    } = attachment;
    // TODO: we shouldn't have to check if these properties have values - they are non-nullable
    if ((0, _valueChecker.doesHaveValue)(testCaseStartedId) && (0, _valueChecker.doesHaveValue)(testStepId)) {
      const {
        stepAttachments
      } = this.testCaseAttemptDataMap[testCaseStartedId];
      if ((0, _valueChecker.doesNotHaveValue)(stepAttachments[testStepId])) {
        stepAttachments[testStepId] = [];
      }
      stepAttachments[testStepId].push(attachment);
    }
  }
  storeTestStepResult({
    testCaseStartedId,
    testStepId,
    testStepResult
  }) {
    this.testCaseAttemptDataMap[testCaseStartedId].stepResults[testStepId] = testStepResult;
  }
  storeTestCaseResult({
    testCaseStartedId,
    willBeRetried
  }) {
    const stepResults = Object.values(this.testCaseAttemptDataMap[testCaseStartedId].stepResults);
    this.testCaseAttemptDataMap[testCaseStartedId].worstTestStepResult = messages.getWorstTestStepResult(stepResults);
    this.testCaseAttemptDataMap[testCaseStartedId].willBeRetried = willBeRetried;
  }
}
exports.default = EventDataCollector;