"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getGherkinExampleRuleMap = getGherkinExampleRuleMap;
exports.getGherkinScenarioLocationMap = getGherkinScenarioLocationMap;
exports.getGherkinScenarioMap = getGherkinScenarioMap;
exports.getGherkinStepMap = getGherkinStepMap;
var _valueChecker = require("../valueChecker");
/**
 * Based on: https://github.com/cucumber/cucumber-js/blob/main/src/formatter/helpers/gherkin_document_parser.ts
 */

function getGherkinStepMap(gherkinDocument) {
  var _gherkinDocument$feat;
  const result = {};
  (_gherkinDocument$feat = gherkinDocument.feature) === null || _gherkinDocument$feat === void 0 || _gherkinDocument$feat.children.map(extractStepContainers).flat().forEach(x => x.steps.forEach(step => result[step.id] = step));
  return result;
}
function extractStepContainers(child) {
  if ((0, _valueChecker.doesHaveValue)(child.background)) {
    return [child.background];
  } else if ((0, _valueChecker.doesHaveValue)(child.rule)) {
    return child.rule.children.map(ruleChild => (0, _valueChecker.doesHaveValue)(ruleChild.background) ? ruleChild.background : ruleChild.scenario).filter(v => !!v);
  } else if ((0, _valueChecker.doesHaveValue)(child.scenario)) {
    return [child.scenario];
  } else {
    throw new Error('Empty step container');
  }
}
function getGherkinScenarioMap(gherkinDocument) {
  var _gherkinDocument$feat2;
  const result = {};
  (_gherkinDocument$feat2 = gherkinDocument.feature) === null || _gherkinDocument$feat2 === void 0 || _gherkinDocument$feat2.children.map(child => {
    if ((0, _valueChecker.doesHaveValue)(child.rule)) {
      return child.rule.children;
    }
    return [child];
  }).flat().forEach(x => {
    if (x.scenario != null) {
      result[x.scenario.id] = x.scenario;
    }
  });
  return result;
}
function getGherkinExampleRuleMap(gherkinDocument) {
  var _gherkinDocument$feat3;
  const result = {};
  (_gherkinDocument$feat3 = gherkinDocument.feature) === null || _gherkinDocument$feat3 === void 0 || _gherkinDocument$feat3.children.filter(x => x.rule != null).forEach(x => {
    var _x$rule;
    return x === null || x === void 0 || (_x$rule = x.rule) === null || _x$rule === void 0 ? void 0 : _x$rule.children.filter(child => (0, _valueChecker.doesHaveValue)(child.scenario)).forEach(child => {
      var _child$scenario;
      if (child !== null && child !== void 0 && (_child$scenario = child.scenario) !== null && _child$scenario !== void 0 && _child$scenario.id && x.rule) {
        result[child.scenario.id] = x.rule;
      }
    });
  });
  return result;
}
function getGherkinScenarioLocationMap(gherkinDocument) {
  const locationMap = {};
  const scenarioMap = getGherkinScenarioMap(gherkinDocument);
  Object.keys(scenarioMap).forEach(id => {
    const scenario = scenarioMap[id];
    locationMap[id] = scenario.location;
    if ((0, _valueChecker.doesHaveValue)(scenario.examples)) {
      scenario.examples.forEach(x => x.tableBody.forEach(tableRow => locationMap[tableRow.id] = tableRow.location));
    }
  });
  return locationMap;
}