"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getColorFns;
var _chalk = _interopRequireDefault(require("chalk"));
var _supportsColor = require("supports-color");
var _valueChecker = require("../valueChecker");
function getColorFns(stream, env, enabled) {
  const support = detectSupport(stream, env, enabled);
  if (support) {
    const chalkInstance = new _chalk.default.Instance(support);
    return {
      forStatus(status) {
        return {
          AMBIGUOUS: chalkInstance.red.bind(_chalk.default),
          FAILED: chalkInstance.red.bind(_chalk.default),
          PASSED: chalkInstance.green.bind(_chalk.default),
          PENDING: chalkInstance.yellow.bind(_chalk.default),
          SKIPPED: chalkInstance.cyan.bind(_chalk.default),
          UNDEFINED: chalkInstance.yellow.bind(_chalk.default),
          UNKNOWN: chalkInstance.yellow.bind(_chalk.default)
        }[status];
      },
      location: chalkInstance.gray.bind(_chalk.default),
      tag: chalkInstance.cyan.bind(_chalk.default),
      diffAdded: chalkInstance.green.bind(_chalk.default),
      diffRemoved: chalkInstance.red.bind(_chalk.default),
      errorMessage: chalkInstance.red.bind(_chalk.default),
      errorStack: chalkInstance.grey.bind(_chalk.default)
    };
  } else {
    return {
      forStatus() {
        return x => x;
      },
      location: x => x,
      tag: x => x,
      diffAdded: x => x,
      diffRemoved: x => x,
      errorMessage: x => x,
      errorStack: x => x
    };
  }
}
function detectSupport(stream, env, enabled) {
  const support = (0, _supportsColor.supportsColor)(stream);
  // if we find FORCE_COLOR, we can let the supports-color library handle that
  if ('FORCE_COLOR' in env || (0, _valueChecker.doesNotHaveValue)(enabled)) {
    return support;
  }
  return enabled ? support || {
    level: 1
  } : false;
}