"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.FeaturesLoader = void 0;
var _gherkinStreams = require("@cucumber/gherkin-streams");
var _gherkinUtils = require("@cucumber/gherkin-utils");
/**
 * Load features.
 *
 * See: https://github.com/cucumber/cucumber-js/blob/main/src/api/load_sources.ts
 * See: https://github.com/cucumber/cucumber-js/blob/main/src/api/gherkin.ts
 */

class FeaturesLoader {
  gherkinQuery = new _gherkinUtils.Query();
  parseErrors = [];
  /**
     * Loads and parses feature files.
     * - featurePaths should be absolute.
     *   See: https://github.com/cucumber/gherkin-streams/blob/main/src/GherkinStreams.ts#L36
     * - if options.relativeTo is provided, uri in gherkin documents will be relative to it.
     *   See: https://github.com/cucumber/gherkin-streams/blob/main/src/SourceMessageStream.ts#L31
     * - options.defaultDialect is 'en' by default.
     *   See: https://github.com/cucumber/gherkin-streams/blob/main/src/makeGherkinOptions.ts#L5
     */
  async load(featurePaths, options) {
    this.gherkinQuery = new _gherkinUtils.Query();
    this.parseErrors = [];
    await gherkinFromPaths(featurePaths, options, envelope => {
      this.gherkinQuery.update(envelope);
      if (envelope.parseError) {
        this.parseErrors.push(envelope.parseError);
      }
    });
  }
  getDocumentsCount() {
    return this.gherkinQuery.getGherkinDocuments().length;
  }
  getDocumentsWithPickles() {
    return this.gherkinQuery.getGherkinDocuments().map(gherkinDocument => {
      const pickles = this.getDocumentPickles(gherkinDocument);
      return {
        ...gherkinDocument,
        pickles
      };
    });
  }
  getDocumentPickles(gherkinDocument) {
    return this.gherkinQuery.getPickles().filter(pickle => gherkinDocument.uri === pickle.uri).map(pickle => this.getPickleWithLocation(pickle));
  }
  getPickleWithLocation(pickle) {
    const lastAstNodeId = pickle.astNodeIds[pickle.astNodeIds.length - 1];
    const location = this.gherkinQuery.getLocation(lastAstNodeId);
    return {
      ...pickle,
      location
    };
  }
}
exports.FeaturesLoader = FeaturesLoader;
async function gherkinFromPaths(paths, options, onEnvelope) {
  return new Promise((resolve, reject) => {
    const gherkinMessageStream = _gherkinStreams.GherkinStreams.fromPaths(paths, options);
    gherkinMessageStream.on('data', onEnvelope);
    gherkinMessageStream.on('end', resolve);
    gherkinMessageStream.on('error', reject);
  });
}