"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.findStepDefinition = findStepDefinition;
exports.hasTsNodeRegister = hasTsNodeRegister;
exports.loadSteps = loadSteps;
var _api = require("@cucumber/cucumber/api");
var _transform = require("../playwright/transform");
var _exit = require("../utils/exit");
const cache = new Map();
async function loadSteps(runConfiguration, environment = {}) {
  const cacheKey = JSON.stringify(runConfiguration);
  let lib = cache.get(cacheKey);
  if (!lib) {
    // use Playwright's built-in hook to compile TypeScript steps
    const uninstall = !hasTsNodeRegister(runConfiguration) ? (0, _transform.installTransform)() : () => {};
    lib = (0, _api.loadSupport)(runConfiguration, environment).finally(() => uninstall());
    cache.set(cacheKey, lib);
  }
  return lib;
}
/**
 * Finds step definition by step text.
 * See: https://github.com/cucumber/cucumber-js/blob/main/src/runtime/assemble_test_cases.ts#L103
 *
 * Handling case when several step definitions found:
 * https://github.com/cucumber/cucumber-js/blob/main/src/runtime/test_case_runner.ts#L313
 */
function findStepDefinition(supportCodeLibrary, stepText, file) {
  const matchedSteps = supportCodeLibrary.stepDefinitions.filter(step => {
    return step.matchesStepName(stepText);
  });
  if (matchedSteps.length === 0) {
    return;
  }
  if (matchedSteps.length > 1) {
    (0, _exit.exit)([`Multiple step definitions matched for text: "${stepText}" (${file})`,
    // todo: print location of every step definition (as in cucumber)
    ...matchedSteps.map(s => `  ${s.pattern}`)].join('\n'));
  }
  return matchedSteps[0];
}
function hasTsNodeRegister(runConfiguration) {
  return runConfiguration.support.requireModules.includes('ts-node/register');
}