"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.resovleFeaturePaths = resovleFeaturePaths;
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
var _environment = require("@cucumber/cucumber/lib/api/environment");
var _console_logger = require("@cucumber/cucumber/lib/api/console_logger");
var _utils = require("../utils");
/**
 * Representation of https://github.com/cucumber/cucumber-js/blob/main/src/paths/paths.ts
 * Since Cucumber 10.1 resolvePaths was moved from lib/api/paths to lib/paths/paths.
 * This module makes resolvePaths working with any version of Cucumber.
 * See: https://github.com/cucumber/cucumber-js/pull/2361/files
 *
 * todo: replace with own paths resolution.
 */

/**
 * Returns list of absolute feature paths.
 */
// eslint-disable-next-line max-statements
async function resovleFeaturePaths(runConfiguration, environment = {}) {
  const {
    cwd,
    stderr,
    debug
  } = (0, _environment.mergeEnvironment)(environment);
  const logger = new _console_logger.ConsoleLogger(stderr, debug);
  const cucumberRoot = (0, _utils.resolvePackageRoot)('@cucumber/cucumber');
  const pathsModuleBefore10_1 = _path.default.join(cucumberRoot, 'lib/api/paths.js');
  const pathsModuleAfter10_1 = _path.default.join(cucumberRoot, 'lib/paths/paths.js');
  const isNewResolvePaths = _fs.default.existsSync(pathsModuleAfter10_1);
  if (isNewResolvePaths) {
    const {
      resolvePaths
    } = require(pathsModuleAfter10_1);
    const {
      sourcePaths,
      unexpandedSourcePaths
    } = await resolvePaths(logger, cwd, runConfiguration.sources);
    return {
      featurePaths: sourcePaths,
      unexpandedFeaturePaths: unexpandedSourcePaths
    };
  } else {
    const {
      resolvePaths
    } = require(pathsModuleBefore10_1);
    const {
      featurePaths,
      unexpandedFeaturePaths
    } = await resolvePaths(logger, cwd, runConfiguration.sources);
    return {
      featurePaths,
      unexpandedFeaturePaths
    };
  }
}