"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.extractFixtureNames = extractFixtureNames;
exports.extractFixtureNamesFromFnBodyMemo = extractFixtureNamesFromFnBodyMemo;
var _fixtureParameterNames = require("../playwright/fixtureParameterNames");
var _bddFixtures = require("../run/bddFixtures");
var _exit = require("../utils/exit");
const bodyFixturesSymbol = Symbol('bodyFixtures');
/**
 * This function is used for playwright-style steps and decorators.
 * It extracts fixtures names from first parameter of function
 * using Playwright's helper.
 */
function extractFixtureNames(fn) {
  return (0, _fixtureParameterNames.fixtureParameterNames)(fn).filter(name => !(0, _bddFixtures.isBddAutoInjectFixture)(name));
}
/**
 * This function is used for cucumber-style steps.
 * It looks for `this.useFixture('xxx')` entries in function body
 * and extracts fixtures names from it.
 */
function extractFixtureNamesFromFnBodyMemo(fn) {
  if (typeof fn !== 'function') {
    return [];
  }
  const fnWithFixtures = fn;
  if (!fnWithFixtures[bodyFixturesSymbol]) {
    fnWithFixtures[bodyFixturesSymbol] = extractFixtureNamesFromFnBody(fn).filter(name => !(0, _bddFixtures.isBddAutoInjectFixture)(name));
  }
  return fnWithFixtures[bodyFixturesSymbol];
}
function extractFixtureNamesFromFnBody(fn) {
  const matches = fn.toString().matchAll(/this\.useFixture\((.+)\)/gi) || [];
  return [...matches].map(match => getFixtureName(match[1]));
}
function getFixtureName(arg) {
  if (!/^['"`]/.test(arg)) {
    // todo: log file location with incorrect useFixture
    (0, _exit.exit)('this.useFixture() can accept only static string as an argument.');
  }
  if (arg.startsWith('`') && arg.includes('${')) {
    (0, _exit.exit)('this.useFixture() can accept only static string as an argument.');
  }
  return arg.replace(/['"`]/g, '');
}