"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SpecialTags = void 0;
/**
 * Special tags.
 */
class SpecialTags {
  ownTags;
  allTags;
  only;
  skip;
  fixme;
  fail;
  retries;
  timeout;
  mode;
  constructor(ownTags, allTags) {
    this.ownTags = ownTags;
    this.allTags = allTags;
    this.extractFlags();
    this.extractRetries();
    this.extractTimeout();
    this.extractMode();
  }
  extractFlags() {
    // order is important
    const flags = ['only', 'fail', 'skip', 'fixme'];
    for (const flag of flags) {
      if (this.ownTags.includes(`@${flag}`)) {
        this[flag] = true;
        return;
      }
    }
    // describe.fail is not supported, so mark all nested tests as failed instead
    if (this.allTags.includes(`@fail`)) {
      this.fail = true;
    }
  }
  extractRetries() {
    for (const tag of this.ownTags.reverse()) {
      const match = tag.match(/@retries:(\d+)/i);
      if (match) {
        this.retries = Number(match[1]);
        return;
      }
    }
  }
  extractTimeout() {
    for (const tag of this.ownTags.reverse()) {
      const match = tag.match(/@timeout:(\d+)/i);
      if (match) {
        this.timeout = Number(match[1]);
        return;
      }
    }
  }
  extractMode() {
    for (const tag of this.ownTags.reverse()) {
      const match = tag.match(/@mode:(default|parallel|serial)/i);
      if (match) {
        this.mode = match[1];
        return;
      }
    }
  }
}
exports.SpecialTags = SpecialTags;