"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TestNode = void 0;
var _utils = require("../utils");
var _specialTags = require("./specialTags");
/**
 * Universal TestNode class representing test or suite in a test file.
 * Holds parent-child links.
 * Allows to inherit tags and titles path.
 */

class TestNode {
  title;
  titlePath;
  ownTags;
  tags;
  specialTags;
  constructor(gherkinNode, parent) {
    this.title = gherkinNode.name;
    this.titlePath = ((parent === null || parent === void 0 ? void 0 : parent.titlePath) || []).concat([this.title]);
    this.ownTags = (0, _utils.removeDuplicates)(getTagNames(gherkinNode.tags));
    this.tags = (0, _utils.removeDuplicates)(((parent === null || parent === void 0 ? void 0 : parent.tags) || []).concat(this.ownTags));
    this.specialTags = new _specialTags.SpecialTags(this.ownTags, this.tags);
  }
  isSkipped() {
    return this.specialTags.skip || this.specialTags.fixme;
  }
}
exports.TestNode = TestNode;
function getTagNames(tags) {
  return tags.map(tag => tag.name);
}