"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getWorkerHooksFixtures = getWorkerHooksFixtures;
exports.runWorkerHooks = runWorkerHooks;
exports.workerHookFactory = workerHookFactory;
var _fixtureParameterNames = require("../playwright/fixtureParameterNames");
var _utils = require("../utils");
/**
 * Worker-level hooks: BeforeAll / AfterAll.
 */

const workerHooks = [];
let workerHooksFixtures;
/**
 * Returns BeforeAll() / AfterAll() functions.
 */
function workerHookFactory(type) {
  return (...args) => {
    addHook({
      type,
      options: getOptionsFromArgs(args),
      fn: getFnFromArgs(args)
    });
  };
}
// eslint-disable-next-line complexity
async function runWorkerHooks(type, fixtures) {
  let error;
  for (const hook of workerHooks) {
    if (hook.type !== type) {
      continue;
    }
    const {
      timeout
    } = hook.options;
    try {
      await (0, _utils.callWithTimeout)(() => hook.fn(fixtures), timeout, getTimeoutMessage(hook));
    } catch (e) {
      if (type === 'beforeAll') {
        throw e;
      }
      if (!error) {
        error = e;
      }
    }
  }
  if (error) {
    throw error;
  }
}
function getWorkerHooksFixtures() {
  if (!workerHooksFixtures) {
    const fixturesFakeObj = {
      $workerInfo: null
    };
    const set = new Set();
    workerHooks.forEach(hook => {
      (0, _fixtureParameterNames.fixtureParameterNames)(hook.fn).filter(fixtureName => !Object.prototype.hasOwnProperty.call(fixturesFakeObj, fixtureName)).forEach(fixtureName => set.add(fixtureName));
    });
    workerHooksFixtures = [...set];
  }
  return workerHooksFixtures;
}
function getOptionsFromArgs(args) {
  if (typeof args[0] === 'object') {
    return args[0];
  }
  return {};
}
function getFnFromArgs(args) {
  return args.length === 1 ? args[0] : args[1];
}
function addHook(hook) {
  if (hook.type === 'beforeAll') {
    workerHooks.push(hook);
  } else {
    // 'afterAll' hooks run in reverse order
    workerHooks.unshift(hook);
  }
}
function getTimeoutMessage(hook) {
  const {
    timeout
  } = hook.options;
  return `${hook.type} hook timeout (${timeout} ms)`;
}