"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.loadConfig = loadConfig;
exports.resolveConfigFile = resolveConfigFile;
var _path = _interopRequireDefault(require("path"));
var _fs = _interopRequireDefault(require("fs"));
var _utils = require("./utils");
var _transform = require("./transform");
var _exit = require("../utils/exit");
/**
 * Loading Playwright config.
 * See: https://github.com/microsoft/playwright/blob/main/packages/playwright-test/src/common/configLoader.ts
 */

async function loadConfig(cliConfigPath) {
  const resolvedConfigFile = resolveConfigFile(cliConfigPath);
  assertConfigFileExists(resolvedConfigFile, cliConfigPath);
  await (0, _transform.requireTransform)().requireOrImport(resolvedConfigFile);
  return {
    resolvedConfigFile
  };
}
function resolveConfigFile(cliConfigPath) {
  const {
    resolveConfigFile
  } = (0, _utils.requirePlaywrightModule)('lib/common/configLoader.js');
  const configFileOrDirectory = getConfigFilePath(cliConfigPath);
  return resolveConfigFile(configFileOrDirectory) || '';
}
function getConfigFilePath(cliConfigPath) {
  return cliConfigPath ? _path.default.resolve(process.cwd(), cliConfigPath) : process.cwd();
}
function assertConfigFileExists(resolvedConfigFile, cliConfigPath) {
  if (!resolvedConfigFile || !_fs.default.existsSync(resolvedConfigFile)) {
    const configFilePath = getConfigFilePath(cliConfigPath);
    (0, _exit.exit)(`Can't find Playwright config file in: ${configFilePath}`);
  }
}