"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getPlaywrightModulePath = getPlaywrightModulePath;
exports.playwrightVersion = void 0;
exports.requirePlaywrightModule = requirePlaywrightModule;
exports.updateAnnotation = updateAnnotation;
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
var _utils = require("../utils");
// cache playwright root
let playwrightRoot = '';
const playwrightVersion = exports.playwrightVersion = (0, _utils.getPackageVersion)('@playwright/test');
/**
 * Requires Playwright's internal module that is not exported via package.exports.
 */
function requirePlaywrightModule(modulePath) {
  const absPath = _path.default.isAbsolute(modulePath) ? modulePath : getPlaywrightModulePath(modulePath);
  return require(absPath);
}
function getPlaywrightModulePath(relativePath) {
  return _path.default.join(getPlaywrightRoot(), relativePath);
}
function getPlaywrightRoot() {
  if (!playwrightRoot) {
    // Since 1.38 all modules moved from @playwright/test to playwright.
    // Here we check existance of 'lib' dir instead of checking version.
    // See: https://github.com/microsoft/playwright/pull/26946
    const playwrightTestRoot = (0, _utils.resolvePackageRoot)('@playwright/test');
    const libDir = _path.default.join(playwrightTestRoot, 'lib');
    playwrightRoot = _fs.default.existsSync(libDir) ? playwrightTestRoot : (0, _utils.resolvePackageRoot)('playwright');
  }
  return playwrightRoot;
}
/**
 * Create or update annotation with provided type.
 */
function updateAnnotation(testInfo, annotation, {
  create = false
} = {}) {
  const {
    annotations
  } = testInfo;
  const index = annotations.findIndex(a => a.type === annotation.type);
  if (index === -1 && !create) {
    throw new Error(`Annotation "${annotation.type}" is not found.`);
  }
  if (index === -1) {
    annotations.push(annotation);
  } else {
    annotations[index] = annotation;
  }
}