"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _path = _interopRequireDefault(require("path"));
var _fs = _interopRequireDefault(require("fs"));
var _promises = require("node:stream/promises");
/**
 * Base reporter for Cucumber reporters.
 * Reference: https://github.com/cucumber/cucumber-js/blob/main/src/formatter/index.ts
 */

class BaseReporter {
  internalOptions;
  outputStream = process.stdout;
  constructor(internalOptions) {
    this.internalOptions = internalOptions;
  }
  get eventBroadcaster() {
    return this.internalOptions.eventBroadcaster;
  }
  get eventDataCollector() {
    return this.internalOptions.eventDataCollector;
  }
  printsToStdio() {
    return isStdout(this.outputStream);
  }
  async init() {}
  async finished() {
    if (!isStdout(this.outputStream)) {
      this.outputStream.end();
      await (0, _promises.finished)(this.outputStream);
    }
  }
  setOutputStream(outputFile) {
    if (!outputFile) {
      return;
    }
    const absolutePath = _path.default.resolve(this.internalOptions.cwd, outputFile);
    _fs.default.mkdirSync(_path.default.dirname(absolutePath), {
      recursive: true
    });
    this.outputStream = _fs.default.createWriteStream(absolutePath);
  }
}
exports.default = BaseReporter;
function isStdout(stream) {
  return stream === process.stdout;
}