"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _base = _interopRequireDefault(require("./base"));
var _loadUtils = require("../../playwright/loadUtils");
var _getColorFns = _interopRequireDefault(require("../../cucumber/formatter/getColorFns"));
/**
 * Custom Cucumber reporter.
 * See: https://github.com/cucumber/cucumber-js/blob/main/docs/custom_formatters.md
 */

class CustomReporter extends _base.default {
  reporterPathOrModule;
  userOptions;
  formatter;
  constructor(internalOptions, reporterPathOrModule, userOptions = {}) {
    super(internalOptions);
    this.reporterPathOrModule = reporterPathOrModule;
    this.userOptions = userOptions;
    this.setOutputStream(this.userOptions.outputFile);
  }
  printsToStdio() {
    // currently always return true, b/c loading of custom reporter is async,
    // but printsToStdio() is called synchronously at the beginning.
    return true;
  }
  async init() {
    const formatterOptions = this.buildFormatterOptions();
    const FormatterConstructor = await this.loadFormatterFromFile();
    this.formatter = new FormatterConstructor(formatterOptions);
  }
  async finished() {
    var _this$formatter;
    await ((_this$formatter = this.formatter) === null || _this$formatter === void 0 ? void 0 : _this$formatter.finished());
    await super.finished();
  }
  async loadFormatterFromFile() {
    // see: https://github.com/microsoft/playwright/blob/main/packages/playwright/src/common/config.ts#L225
    const reporterPath = require.resolve(this.reporterPathOrModule, {
      paths: [this.internalOptions.cwd]
    });
    return (0, _loadUtils.requireOrImportDefaultFunction)(reporterPath, true);
  }
  buildFormatterOptions() {
    const colorFns = (0, _getColorFns.default)(this.outputStream, process.env, this.userOptions.colorsEnabled);
    return {
      cwd: this.internalOptions.cwd,
      eventBroadcaster: this.eventBroadcaster,
      eventDataCollector: this.eventDataCollector,
      parsedArgvOptions: this.userOptions,
      colorFns,
      stream: this.outputStream,
      log: this.outputStream.write.bind(this.outputStream),
      cleanup: async () => {},
      snippetBuilder: null,
      supportCodeLibrary: {
        World: {}
      }
    };
  }
}
// const fakeSuportCodeLibrary = {
//   parameterTypeRegistry: ParameterTypeRegistry;
// stepDefinitions: StepDefinition[];
// // eslint-disable-next-line @typescript-eslint/no-explicit-any
// World: any;
// originalCoordinates: ISupportCodeCoordinates;
// }
exports.default = CustomReporter;