"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var _events = _interopRequireDefault(require("events"));
var _messagesBuilder = require("./messagesBuilder");
var _configDir = require("../../config/configDir");
var _enrichReporterData = require("../../config/enrichReporterData");
var _message = _interopRequireDefault(require("./message"));
var _html = _interopRequireDefault(require("./html"));
var _junit = _interopRequireDefault(require("./junit"));
var _json = _interopRequireDefault(require("./json"));
var _custom = _interopRequireDefault(require("./custom"));
/**
 * Playwright reporter that generates different Cucumber reports.
 */

const builtinReporters = {
  html: _html.default,
  message: _message.default,
  junit: _junit.default,
  json: _json.default
};
class CucumberReporterAdapter {
  messagesBuilderRef;
  type;
  userOptions;
  reporter;
  constructor(fullOptions) {
    const {
      $type,
      ...userOptions
    } = fullOptions;
    this.type = $type;
    this.userOptions = userOptions;
    (0, _enrichReporterData.enableEnrichReporterData)();
    this.messagesBuilderRef = (0, _messagesBuilder.getMessagesBuilderRef)();
    this.reporter = this.createCucumberReporter();
  }
  printsToStdio() {
    return this.reporter.printsToStdio();
  }
  onTestEnd(test, result) {
    this.messagesBuilderRef.onTestEnd(test, result);
  }
  async onEnd(result) {
    this.messagesBuilderRef.onEnd(result);
    await this.reporter.init();
    await this.messagesBuilderRef.builder.buildMessages();
    this.messagesBuilderRef.builder.emitMessages(this.reporter.eventBroadcaster);
    await this.reporter.finished();
  }
  createCucumberReporter() {
    const internalOptions = {
      cwd: (0, _configDir.getPlaywrightConfigDir)(),
      eventBroadcaster: new _events.default(),
      eventDataCollector: this.messagesBuilderRef.builder.eventDataCollector
    };
    if (isBuiltInReporter(this.type)) {
      const BuiltInReporter = builtinReporters[this.type];
      return new BuiltInReporter(internalOptions, this.userOptions);
    } else {
      const reporterPath = this.type;
      return new _custom.default(internalOptions, reporterPath, this.userOptions);
    }
  }
}
exports.default = CucumberReporterAdapter;
function isBuiltInReporter(type) {
  return type in builtinReporters;
}