"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
var messages = _interopRequireWildcard(require("@cucumber/messages"));
var _base = _interopRequireDefault(require("./base"));
var GherkinDocumentParser = _interopRequireWildcard(require("../../cucumber/formatter/GherkinDocumentParser"));
var PickleParser = _interopRequireWildcard(require("../../cucumber/formatter/PickleParser"));
var _valueChecker = require("../../cucumber/valueChecker");
var _stepArguments = require("../../cucumber/stepArguments");
var _durationHelpers = require("../../cucumber/formatter/durationHelpers");
var _locationHelpers = require("../../cucumber/formatter/locationHelpers");
var _GherkinDocument = require("./messagesBuilder/GherkinDocument");
var _Projects = require("./messagesBuilder/Projects");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Cucumber json reporter.
 * Based on: https://github.com/cucumber/cucumber-js/blob/main/src/formatter/json_formatter.ts
 *
 * Although json reporter is marked as deprecated in CucumberJS docs
 * (see https://github.com/cucumber/cucumber-js/blob/main/docs/formatters.md#json),
 * this decision was rolled back:
 * (see https://github.com/cucumber/json-formatter/issues/34).
 *
 * See also: separate tool to convert cucumber messages to cucumber json:
 * https://github.com/vrymar/cucumber-json-report-formatter/tree/master
 */
/* eslint-disable max-lines, max-statements, max-nested-callbacks, complexity */

const {
  getGherkinExampleRuleMap,
  getGherkinScenarioLocationMap,
  getGherkinStepMap,
  getGherkinScenarioMap
} = GherkinDocumentParser;
const {
  getScenarioDescription,
  getPickleStepMap,
  getStepKeyword
} = PickleParser;
class JsonReporter extends _base.default {
  userOptions;
  // for now omit step definitions
  supportCodeLibrary = {
    stepDefinitions: []
  };
  constructor(internalOptions, userOptions = {}) {
    super(internalOptions);
    this.userOptions = userOptions;
    this.setOutputStream(this.userOptions.outputFile);
    this.eventBroadcaster.on('envelope', envelope => {
      if ((0, _valueChecker.doesHaveValue)(envelope.testRunFinished)) {
        this.onTestRunFinished();
      }
    });
  }
  convertNameToId(obj) {
    return obj.name.replace(/ /g, '-').toLowerCase();
  }
  formatDataTable(dataTable) {
    return {
      rows: dataTable.rows.map(row => ({
        cells: row.cells.map(x => x.value)
      }))
    };
  }
  formatDocString(docString, gherkinStep) {
    var _gherkinStep$docStrin;
    return {
      content: docString.content,
      line: (_gherkinStep$docStrin = gherkinStep.docString) === null || _gherkinStep$docStrin === void 0 ? void 0 : _gherkinStep$docStrin.location.line
    };
  }
  formatStepArgument(stepArgument, gherkinStep) {
    if ((0, _valueChecker.doesNotHaveValue)(stepArgument)) {
      return [];
    }
    return [(0, _stepArguments.parseStepArgument)(stepArgument, {
      dataTable: dataTable => this.formatDataTable(dataTable),
      docString: docString => this.formatDocString(docString, gherkinStep)
    })];
  }
  onTestRunFinished() {
    const groupedTestCaseAttempts = {};
    this.eventDataCollector.getTestCaseAttempts().forEach(testCaseAttempt => {
      if (!testCaseAttempt.willBeRetried) {
        const uri = testCaseAttempt.pickle.uri;
        if ((0, _valueChecker.doesNotHaveValue)(groupedTestCaseAttempts[uri])) {
          groupedTestCaseAttempts[uri] = [];
        }
        groupedTestCaseAttempts[uri].push(testCaseAttempt);
      }
    });
    const features = Object.keys(groupedTestCaseAttempts).map(uri => {
      const group = groupedTestCaseAttempts[uri];
      const {
        gherkinDocument
      } = group[0];
      const gherkinStepMap = getGherkinStepMap(gherkinDocument);
      const gherkinScenarioMap = getGherkinScenarioMap(gherkinDocument);
      const gherkinExampleRuleMap = getGherkinExampleRuleMap(gherkinDocument);
      const gherkinScenarioLocationMap = getGherkinScenarioLocationMap(gherkinDocument);
      const elements = group.map(testCaseAttempt => {
        const {
          pickle
        } = testCaseAttempt;
        const pickleStepMap = getPickleStepMap(pickle);
        let isBeforeHook = true;
        const steps = testCaseAttempt.testCase.testSteps.map(testStep => {
          isBeforeHook = isBeforeHook && !(0, _valueChecker.doesHaveValue)(testStep.pickleStepId);
          return this.getStepData({
            isBeforeHook,
            gherkinStepMap,
            pickleStepMap,
            testStep,
            testStepAttachments: testCaseAttempt.stepAttachments[testStep.id],
            testStepResult: testCaseAttempt.stepResults[testStep.id]
          });
        });
        return this.getScenarioData({
          feature: gherkinDocument.feature,
          gherkinScenarioLocationMap,
          gherkinExampleRuleMap,
          gherkinScenarioMap,
          pickle,
          steps
        });
      });
      return this.getFeatureData({
        gherkinDocument,
        elements
      });
    });
    this.outputStream.write(JSON.stringify(features, null, 2));
  }
  getFeatureData({
    gherkinDocument,
    elements
  }) {
    const meta = _GherkinDocument.GherkinDocumentMessage.extractMeta(gherkinDocument);
    const feature = gherkinDocument.feature;
    const featureNameWithProject = (0, _Projects.getFeatureNameWithProject)(meta.projectName, feature.name);
    return {
      description: feature.description,
      elements,
      id: this.convertNameToId({
        name: featureNameWithProject
      }),
      line: feature.location.line,
      keyword: feature.keyword,
      name: this.userOptions.addProjectToFeatureName ? featureNameWithProject : feature.name,
      tags: this.getFeatureTags(feature),
      uri: meta.originalUri,
      metadata: this.getFeatureMetadata(gherkinDocument)
    };
  }
  getFeatureMetadata(gherkinDocument) {
    if (!this.userOptions.addMetadata) {
      return;
    }
    const meta = _GherkinDocument.GherkinDocumentMessage.extractMeta(gherkinDocument);
    const metadata = {
      Project: meta.projectName || '',
      Browser: meta.browserName || ''
    };
    return this.userOptions.addMetadata === 'object' ? metadata : Object.keys(metadata).map(name => ({
      name,
      value: metadata[name]
    }));
  }
  getScenarioData({
    feature,
    gherkinScenarioLocationMap,
    gherkinExampleRuleMap,
    gherkinScenarioMap,
    pickle,
    steps
  }) {
    const description = getScenarioDescription({
      pickle,
      gherkinScenarioMap
    });
    return {
      description,
      id: this.formatScenarioId({
        feature,
        pickle,
        gherkinExampleRuleMap
      }),
      keyword: gherkinScenarioMap[pickle.astNodeIds[0]].keyword,
      line: gherkinScenarioLocationMap[pickle.astNodeIds[pickle.astNodeIds.length - 1]].line,
      name: pickle.name,
      steps,
      tags: this.getScenarioTags({
        feature,
        pickle,
        gherkinScenarioMap
      }),
      type: 'scenario'
    };
  }
  formatScenarioId({
    feature,
    pickle,
    gherkinExampleRuleMap
  }) {
    let parts;
    const rule = gherkinExampleRuleMap[pickle.astNodeIds[0]];
    if ((0, _valueChecker.doesHaveValue)(rule)) {
      parts = [feature, rule, pickle];
    } else {
      parts = [feature, pickle];
    }
    return parts.map(part => this.convertNameToId(part)).join(';');
  }
  getStepData({
    isBeforeHook,
    gherkinStepMap,
    pickleStepMap,
    testStep,
    testStepAttachments,
    testStepResult
  }) {
    const data = {};
    if ((0, _valueChecker.doesHaveValue)(testStep.pickleStepId)) {
      const pickleStep = pickleStepMap[testStep.pickleStepId];
      data.arguments = this.formatStepArgument(pickleStep.argument, gherkinStepMap[pickleStep.astNodeIds[0]]);
      data.keyword = getStepKeyword({
        pickleStep,
        gherkinStepMap
      });
      data.line = gherkinStepMap[pickleStep.astNodeIds[0]].location.line;
      data.name = pickleStep.text;
    } else {
      data.keyword = isBeforeHook ? 'Before' : 'After';
      data.hidden = true;
    }
    if ((0, _valueChecker.doesHaveValue)(testStep.stepDefinitionIds) && testStep.stepDefinitionIds.length === 1) {
      const stepDefinition = this.supportCodeLibrary.stepDefinitions.find(s => {
        var _testStep$stepDefinit;
        return s.id === ((_testStep$stepDefinit = testStep.stepDefinitionIds) === null || _testStep$stepDefinit === void 0 ? void 0 : _testStep$stepDefinit[0]);
      });
      if ((0, _valueChecker.doesHaveValue)(stepDefinition)) {
        data.match = {
          location: (0, _locationHelpers.formatLocation)(stepDefinition)
        };
      }
    }
    const {
      message,
      status
    } = testStepResult;
    data.result = {
      status: messages.TestStepResultStatus[status].toLowerCase()
    };
    if ((0, _valueChecker.doesHaveValue)(testStepResult.duration)) {
      data.result.duration = (0, _durationHelpers.durationToNanoseconds)(testStepResult.duration);
    }
    if (status === messages.TestStepResultStatus.FAILED && (0, _valueChecker.doesHaveValue)(message)) {
      data.result.error_message = message;
    }
    const allowedAttachments = this.getAllowedAttachments(testStepAttachments);
    if (allowedAttachments && allowedAttachments.length > 0) {
      data.embeddings = allowedAttachments.map(attachment => ({
        data: attachment.contentEncoding === messages.AttachmentContentEncoding.IDENTITY ? Buffer.from(attachment.body).toString('base64') : attachment.body,
        mime_type: attachment.mediaType
      }));
    }
    return data;
  }
  getFeatureTags(feature) {
    return feature.tags.map(tagData => ({
      name: tagData.name,
      line: tagData.location.line
    }));
  }
  getScenarioTags({
    feature,
    pickle,
    gherkinScenarioMap
  }) {
    const scenario = gherkinScenarioMap[pickle.astNodeIds[0]];
    return pickle.tags.map(tagData => this.getScenarioTag(tagData, feature, scenario));
  }
  getScenarioTag(tagData, feature, scenario) {
    var _tag$location;
    const byAstNodeId = tag => tag.id === tagData.astNodeId;
    const flatten = (acc, val) => acc.concat(val);
    const tag = feature.tags.find(byAstNodeId) || scenario.tags.find(byAstNodeId) || scenario.examples.map(e => e.tags).reduce((acc, val) => flatten(acc, val), []).find(byAstNodeId);
    return {
      name: tagData.name,
      line: tag === null || tag === void 0 || (_tag$location = tag.location) === null || _tag$location === void 0 ? void 0 : _tag$location.line
    };
  }
  getAllowedAttachments(testStepAttachments) {
    const {
      skipAttachments
    } = this.userOptions;
    if (Array.isArray(skipAttachments)) {
      return testStepAttachments === null || testStepAttachments === void 0 ? void 0 : testStepAttachments.filter(attachment => {
        return !skipAttachments.includes(attachment.mediaType);
      });
    } else {
      return skipAttachments ? [] : testStepAttachments;
    }
  }
}
exports.default = JsonReporter;