"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GherkinDocumentMessage = void 0;
var _utils = require("../../../utils");
var _Projects = require("./Projects");
const gherkinDocumentMetaSymbol = Symbol('gherkinDocumentMeta');
class GherkinDocumentMessage {
  projectInfo;
  gherkinDocument;
  static extractMeta(gherkinDocument) {
    return gherkinDocument[gherkinDocumentMetaSymbol];
  }
  constructor(projectInfo, gherkinDocument) {
    this.projectInfo = projectInfo;
    this.gherkinDocument = gherkinDocument;
  }
  build() {
    const gherkinDocument = this.copyDocumentWithoutPickles();
    this.setUriWithProject(gherkinDocument);
    this.setMeta(gherkinDocument);
    return {
      gherkinDocument
    };
  }
  copyDocumentWithoutPickles() {
    return (0, _utils.omit)(this.gherkinDocument, 'pickles');
  }
  setUriWithProject(gherkinDocument) {
    gherkinDocument.uri = (0, _Projects.getFeatureUriWithProject)(this.projectInfo, this.gherkinDocument.uri);
  }
  setMeta(gherkinDocument) {
    var _this$projectInfo, _this$projectInfo2;
    gherkinDocument[gherkinDocumentMetaSymbol] = {
      originalUri: this.gherkinDocument.uri || '',
      projectName: (_this$projectInfo = this.projectInfo) === null || _this$projectInfo === void 0 ? void 0 : _this$projectInfo.projectName,
      browserName: (_this$projectInfo2 = this.projectInfo) === null || _this$projectInfo2 === void 0 ? void 0 : _this$projectInfo2.browserName
    };
  }
}
exports.GherkinDocumentMessage = GherkinDocumentMessage;