"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Hook = void 0;
var _crypto = require("crypto");
var _configDir = require("../../../config/configDir");
var _path = _interopRequireDefault(require("path"));
/**
 * Hook that can be used in different test cases.
 * Builds Cucumber's hook message.
 */

class Hook {
  internalId;
  static getInternalId(pwStep) {
    const {
      file,
      line,
      column
    } = pwStep.location || {};
    return [pwStep.category, ...pwStep.titlePath(), file, line, column].join('|');
  }
  id;
  name;
  sourceReference;
  constructor(internalId, /* one of pwSteps for this hook */
  pwStep) {
    this.internalId = internalId;
    this.id = (0, _crypto.randomUUID)();
    this.name = this.getName(pwStep);
    this.sourceReference = this.getSourceReference(pwStep);
  }
  buildMessage() {
    const hook = {
      id: this.id,
      name: this.name,
      sourceReference: this.sourceReference
    };
    return {
      hook
    };
  }
  getName(pwStep) {
    // These fixture names are for anonymous hooks
    // created with Before() / After() functions.
    // Keep name empty for them to be consistent with Cucumber.
    // const bddSystemFixtures = ['fixture: $before', 'fixture: $after'];
    // if (!pwStep.title || bddSystemFixtures.includes(pwStep.title)) return undefined;
    return pwStep.title;
  }
  getSourceReference(pwStep) {
    const {
      file,
      line,
      column
    } = pwStep.location || {};
    const uri = file ? _path.default.relative((0, _configDir.getPlaywrightConfigDir)(), file) : undefined;
    return {
      uri,
      location: line ? {
        line,
        column
      } : undefined
    };
  }
}
exports.Hook = Hook;