"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TITLE_SEPARATOR = void 0;
exports.getFeatureNameWithProject = getFeatureNameWithProject;
exports.getFeatureUriWithProject = getFeatureUriWithProject;
exports.getProjectInfo = getProjectInfo;
var _AutofillMap = require("../../../utils/AutofillMap");
// title separator used in Playwright
const TITLE_SEPARATOR = exports.TITLE_SEPARATOR = ' › ';
const projectsMap = new _AutofillMap.AutofillMap();
function getProjectInfo(test) {
  const project = test.parent.project();
  const projectId = project === null || project === void 0 ? void 0 : project.name;
  return projectsMap.getOrCreate(projectId, () => {
    return {
      projectName: project === null || project === void 0 ? void 0 : project.name,
      // browserName will be empty if not defined in project
      // todo: get browser info from bddData
      browserName: (project === null || project === void 0 ? void 0 : project.use.browserName) || (project === null || project === void 0 ? void 0 : project.use.defaultBrowserType)
    };
  });
}
/**
 * Returns URI prepended with project name.
 * It allows to separate PW projects runs of the same feature file.
 *
 * Now result should not contain spaces as Cucumber HTML report uses it as uuid.
 * See: https://github.com/cucumber/react-components/issues/344
 */
function getFeatureUriWithProject(projectInfo, uri) {
  return projectInfo !== null && projectInfo !== void 0 && projectInfo.projectName && uri ? `[${projectInfo.projectName}]:${uri}` : uri;
}
function getFeatureNameWithProject(projectName, featureName) {
  return projectName ? `${projectName}${TITLE_SEPARATOR}${featureName}` : featureName;
}