"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TestStepAttachments = void 0;
var _fs = _interopRequireDefault(require("fs"));
var messages = _interopRequireWildcard(require("@cucumber/messages"));
var _path = _interopRequireDefault(require("path"));
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/**
 * Class for getting attachment messages for a particular step.
 */

class TestStepAttachments {
  testCaseRun;
  testStep;
  pwStep;
  constructor(testCaseRun, testStep, pwStep) {
    this.testCaseRun = testCaseRun;
    this.testStep = testStep;
    this.pwStep = pwStep;
  }
  buildMessages() {
    if (!this.pwStep) {
      return [];
    }
    return this.testCaseRun.attachmentMapper.getStepAttachments(this.pwStep).map(pwAttachment => this.buildAttachmentMessage(pwAttachment));
  }
  buildAttachmentMessage(pwAttachment) {
    const attachment = {
      testCaseStartedId: this.testCaseRun.id,
      testStepId: this.testStep.id,
      // for now always attach as base64
      // todo: for text/plain and application/json use raw to save some bytes
      body: this.getAttachmentBodyBase64(pwAttachment),
      contentEncoding: messages.AttachmentContentEncoding.BASE64,
      mediaType: pwAttachment.contentType,
      fileName: pwAttachment.name
    };
    return {
      attachment
    };
  }
  getAttachmentBodyBase64(pwAttachment) {
    if (pwAttachment.path) {
      if (_fs.default.existsSync(pwAttachment.path)) {
        return _fs.default.readFileSync(pwAttachment.path, 'base64');
      }
      throw createMissingAttachmentError(pwAttachment.path);
    }
    if (pwAttachment.body) {
      return pwAttachment.body.toString('base64');
    }
    throw new Error(`Playwright attachment without path and body`);
  }
}
exports.TestStepAttachments = TestStepAttachments;
function createMissingAttachmentError(attachmentPath) {
  const attachmentDir = _path.default.join(_path.default.dirname(attachmentPath));
  const attachmentDirExists = _fs.default.existsSync(attachmentDir);
  const files = attachmentDirExists ? _fs.default.readdirSync(attachmentDir) : [];
  const errorMsg = [`Attachment file is not found:`, attachmentPath, `Attachment dir ${attachmentDirExists ? 'exists' : 'does not exist'}.`, ...(attachmentDirExists ? [`Available files (${files.length}):`, ...files] : []), ''].join('\n');
  return new Error(errorMsg);
}