"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TestStepRun = void 0;
var messages = _interopRequireWildcard(require("@cucumber/messages"));
var _stripAnsiEscapes = require("../../../utils/stripAnsiEscapes");
var _timing = require("./timing");
var _TestStepAttachments = require("./TestStepAttachments");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
class TestStepRun {
  testCaseRun;
  testStep;
  pwStep;
  constructor(testCaseRun, testStep, pwStep) {
    this.testCaseRun = testCaseRun;
    this.testStep = testStep;
    this.pwStep = pwStep;
  }
  buildMessages() {
    const stepAttachments = new _TestStepAttachments.TestStepAttachments(this.testCaseRun, this.testStep, this.pwStep);
    return [this.buildTestStepStarted(),
    // prettier-ignore
    ...stepAttachments.buildMessages(), this.buildTestStepFinished()];
  }
  isHook() {
    return Boolean(this.testStep.hookId);
  }
  wasExecuted() {
    return Boolean(this.pwStep);
  }
  get startTime() {
    return this.wasExecuted() ? this.pwStep.startTime : this.testCaseRun.result.startTime;
  }
  get duration() {
    return this.wasExecuted() ? this.pwStep.duration : 0;
  }
  buildTestStepStarted() {
    const testStepStarted = {
      testCaseStartedId: this.testCaseRun.id,
      testStepId: this.testStep.id,
      timestamp: (0, _timing.toCucumberTimestamp)(this.startTime.getTime())
    };
    return {
      testStepStarted
    };
  }
  buildTestStepFinished() {
    const error = this.getStepError();
    const testStepFinished = {
      testCaseStartedId: this.testCaseRun.id,
      testStepId: this.testStep.id,
      testStepResult: {
        duration: messages.TimeConversion.millisecondsToDuration(this.duration),
        status: this.getStatus(error),
        // 'message' is deprecated since cucumber 10.4 in favor of 'exception' field
        // See: https://github.com/cucumber/react-components/pull/345
        message: error ? buildErrorMessage(error) : undefined,
        exception: error ? buildException(error) : undefined
      },
      timestamp: (0, _timing.toCucumberTimestamp)(this.startTime.getTime() + this.duration)
    };
    return {
      testStepFinished
    };
  }
  getStatus(error) {
    switch (true) {
      case Boolean(error):
        return messages.TestStepResultStatus.FAILED;
      // For hooks that were not executted we return PASSED, not SKIPPED.
      // Because these hooks can be from another run attempt of this testCase.
      // If marked as skipped, the whole run is marked as skipped in reporter.
      case !this.isHook() && !this.wasExecuted():
        return messages.TestStepResultStatus.SKIPPED;
      default:
        return messages.TestStepResultStatus.PASSED;
    }
  }
  // eslint-disable-next-line complexity
  getStepError() {
    if (!this.pwStep) {
      return;
    }
    if (this.testCaseRun.errorSteps.has(this.pwStep)) {
      return this.pwStep.error;
    }
    if (this.testCaseRun.isTimeouted() && this.pwStep === this.testCaseRun.timeoutedStep) {
      var _this$testCaseRun$res;
      return {
        message: (_this$testCaseRun$res = this.testCaseRun.result.errors) === null || _this$testCaseRun$res === void 0 ? void 0 : _this$testCaseRun$res.map(e => e.message).join('\n\n')
      };
    }
  }
}
exports.TestStepRun = TestStepRun;
function buildErrorMessage(error) {
  return (0, _stripAnsiEscapes.stripAnsiEscapes)([error.message, error.snippet].filter(Boolean).join('\n'));
}
function buildException(error) {
  return {
    type: 'Error',
    message: buildErrorMessage(error),
    // todo: extract only trace?
    stackTrace: error.stack ? extractStackTrace((0, _stripAnsiEscapes.stripAnsiEscapes)(error.stack)) : undefined
    // Use type casting b/c older versions of @cucumber/messages don't have 'stackTrace' field
    // todo: add direct dependency on @cucumber/messages
  };
}
function extractStackTrace(errorStack) {
  return errorStack.split('\n').filter(line => line.match(/^\s+at .*/)).join('\n');
}