"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.collectStepsDfs = collectStepsDfs;
exports.collectStepsWithCategory = collectStepsWithCategory;
exports.findDeepestStepWithError = findDeepestStepWithError;
exports.findDeepestStepWithUnknownDuration = findDeepestStepWithUnknownDuration;
exports.getHooksRootPwStep = getHooksRootPwStep;
exports.isUnknownDuration = isUnknownDuration;
/**
 * Utility functions for filtering Playwright steps.
 */
// Playwright step categoires, that can be mapped to testStep / hook in Cucumber messages
const MEANINGFUL_STEP_CATEGORIES = ['hook', 'fixture', 'test.step'];
function collectStepsWithCategory(parent, category) {
  const categories = Array.isArray(category) ? category : [category];
  const steps = collectStepsDfs(parent);
  return steps.filter(step => categories.includes(step.category));
}
function getHooksRootPwStep(result, type) {
  const rootStepTitle = type === 'before' ? 'Before Hooks' : 'After Hooks';
  return result.steps.find(step => step.category === 'hook' && step.title === rootStepTitle);
}
function findDeepestStepWithError(root) {
  if (!root) {
    return;
  }
  return findDeepestStepWith(root, pwStep => {
    return Boolean(pwStep.error) && MEANINGFUL_STEP_CATEGORIES.includes(pwStep.category);
  });
}
function findDeepestStepWithUnknownDuration(root) {
  if (!root) {
    return;
  }
  return findDeepestStepWith(root, pwStep => {
    return isUnknownDuration(pwStep) && MEANINGFUL_STEP_CATEGORIES.includes(pwStep.category);
  });
}
/**
 * Finds the deepest step that satisfies predicate function.
 */
function findDeepestStepWith(root, predicate) {
  let currentStep = predicate(root) ? root : undefined;
  while (currentStep) {
    const nextStep = currentStep.steps.find(pwStep => predicate(pwStep));
    if (!nextStep) {
      break;
    }
    currentStep = nextStep;
  }
  return currentStep;
}
/**
 * Returns all steps in DFS order.
 * See: https://en.wikipedia.org/wiki/Depth-first_search
 */
function collectStepsDfs(parent) {
  var _parent$steps;
  return (parent === null || parent === void 0 || (_parent$steps = parent.steps) === null || _parent$steps === void 0 ? void 0 : _parent$steps.reduce((res, step) => {
    res.push(step);
    res.push(...collectStepsDfs(step));
    return res;
  }, [])) || [];
}
function isUnknownDuration(pwStep) {
  return pwStep.duration === -1;
}