"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.StepInvoker = void 0;
var _loadSteps = require("../cucumber/loadSteps");
var _getLocationInFile = require("../playwright/getLocationInFile");
var _testTypeImpl = require("../playwright/testTypeImpl");
var _defineStep = require("../steps/defineStep");
var _lang = require("../config/lang");
/**
 * Class to invoke step in playwright runner.
 */

class StepInvoker {
  world;
  keyword;
  constructor(world, keyword) {
    this.world = world;
    this.keyword = keyword;
    this.invoke = this.invoke.bind(this);
  }
  /**
     * Invokes particular step.
     * See: https://github.com/cucumber/cucumber-js/blob/main/src/runtime/test_case_runner.ts#L299
     */
  async invoke(stepText, argument, stepFixtures) {
    var _this$world$$internal;
    this.world.$internal.currentStepFixtures = stepFixtures || {};
    const stepDefinition = this.getStepDefinition(stepText);
    // Get location of step call in generated test file.
    // This call must be exactly here to have correct call stack (before async calls)
    const location = (0, _getLocationInFile.getLocationInFile)(this.world.testInfo.file);
    const stepTitle = this.getStepTitle(stepText);
    const code = (0, _defineStep.getStepCode)(stepDefinition);
    const parameters = await this.getStepParameters(stepDefinition, stepText, argument || undefined);
    (_this$world$$internal = this.world.$internal.bddDataManager) === null || _this$world$$internal === void 0 || _this$world$$internal.registerStep(stepDefinition, stepText, location);
    await (0, _testTypeImpl.runStepWithCustomLocation)(this.world.test, stepTitle, location, () => code.apply(this.world, parameters));
  }
  getStepDefinition(text) {
    const stepDefinition = (0, _loadSteps.findStepDefinition)(this.world.options.supportCodeLibrary, text, this.world.testInfo.file);
    if (!stepDefinition) {
      throw new Error(`Undefined step: "${text}"`);
    }
    return stepDefinition;
  }
  async getStepParameters(stepDefinition, text, argument) {
    // see: https://github.com/cucumber/cucumber-js/blob/main/src/models/step_definition.ts#L25
    const {
      parameters
    } = await stepDefinition.getInvocationParameters({
      hookParameter: {},
      // only text and argument are needed
      step: {
        text,
        argument
      },
      world: this.world
    });
    return parameters;
  }
  getStepTitle(text) {
    // Currently prepend keyword only for English.
    // For other langs it's more complex as we need to pass original keyword from step.
    return (0, _lang.isEnglish)(this.world.options.lang) ? `${this.keyword} ${text}` : text;
  }
}
exports.StepInvoker = StepInvoker;