"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.BddDataManager = void 0;
exports.getBddDataFromTest = getBddDataFromTest;
var _createTestStep = require("../../cucumber/createTestStep");
var _utils = require("../../utils");
var _utils2 = require("../../playwright/utils");
const BDD_DATA_ANNOTATION_NAME = '__bddData';
class BddDataManager {
  testInfo;
  data;
  constructor(testInfo, testMeta, uri) {
    this.testInfo = testInfo;
    this.data = {
      uri,
      pickleLocation: testMeta.pickleLocation,
      steps: []
    };
    this.save({
      create: true
    });
  }
  registerStep(stepDefinition, stepText, pwStepLocation) {
    const step = (0, _createTestStep.createTestStep)(stepDefinition, stepText);
    this.data.steps.push({
      pwStepLocation: (0, _utils.stringifyLocation)(pwStepLocation),
      stepMatchArgumentsLists: step.stepMatchArgumentsLists || []
    });
    this.save();
  }
  save({
    create = false
  } = {}) {
    (0, _utils2.updateAnnotation)(this.testInfo, {
      type: BDD_DATA_ANNOTATION_NAME,
      description: JSON.stringify(this.data)
    }, {
      create
    });
  }
}
exports.BddDataManager = BddDataManager;
function getBddDataFromTest({
  annotations
}) {
  const annotationIndex = annotations.findIndex(isBddDataAnnotation);
  const annotation = annotations[annotationIndex];
  const bddData = annotation !== null && annotation !== void 0 && annotation.description ? JSON.parse(annotation.description) : undefined;
  return {
    bddData,
    annotationIndex
  };
}
function isBddDataAnnotation(annotation) {
  return annotation.type === BDD_DATA_ANNOTATION_NAME;
}