"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.isBddAutoInjectFixture = isBddAutoInjectFixture;
exports.test = void 0;
var _test = require("@playwright/test");
var _loadConfig = require("../cucumber/loadConfig");
var _loadSteps = require("../cucumber/loadSteps");
var _bddWorld = require("./bddWorld");
var _config = require("../config");
var _env = require("../config/env");
var _steps = require("../steps/decorators/steps");
var _configDir = require("../config/configDir");
var _scenario = require("../hooks/scenario");
var _worker = require("../hooks/worker");
var _StepInvoker = require("./StepInvoker");
var _testMeta = require("../gen/testMeta");
var _logger = require("../utils/logger");
var _enrichReporterData = require("../config/enrichReporterData");
var _bddData = require("./bddData");
const test = exports.test = _test.test.extend({
  // load cucumber once per worker (auto-fixture)
  // todo: maybe remove caching in cucumber/loadConfig.ts and cucumber/loadSteps.ts
  // as we call it once per worker. Check generation phase.
  $cucumber: [async ({}, use, workerInfo) => {
    const config = (0, _env.getConfigFromEnv)(workerInfo.project.testDir);
    const environment = {
      cwd: (0, _configDir.getPlaywrightConfigDir)()
    };
    const {
      runConfiguration
    } = await (0, _loadConfig.loadConfig)({
      provided: (0, _config.extractCucumberConfig)(config)
    }, environment);
    const supportCodeLibrary = await (0, _loadSteps.loadSteps)(runConfiguration, environment);
    (0, _steps.appendDecoratorSteps)(supportCodeLibrary);
    const World = (0, _bddWorld.getWorldConstructor)(supportCodeLibrary);
    await use({
      runConfiguration,
      supportCodeLibrary,
      World,
      config
    });
  }, {
    auto: true,
    scope: 'worker'
  }],
  // $lang fixture can be overwritten in test file
  $lang: ({}, use) => use(''),
  // init $bddWorldFixtures with empty object, will be owerwritten in test file for cucumber-style
  $bddWorldFixtures: ({}, use) => use({}),
  $bddWorld: async ({
    $tags,
    $test,
    $bddWorldFixtures,
    $cucumber,
    $lang,
    $testMeta,
    $uri
  }, use, testInfo) => {
    const {
      runConfiguration,
      supportCodeLibrary,
      World,
      config
    } = $cucumber;
    const world = new World({
      testInfo,
      supportCodeLibrary,
      $tags,
      $test,
      $bddWorldFixtures,
      lang: $lang,
      parameters: runConfiguration.runtime.worldParameters || {},
      log: () => _logger.logger.warn(`world.log() is noop, please use world.testInfo.attach()`),
      attach: async () => _logger.logger.warn(`world.attach() is noop, please use world.testInfo.attach()`)
    });
    if ((0, _enrichReporterData.getEnrichReporterData)(config)) {
      world.$internal.bddDataManager = new _bddData.BddDataManager(testInfo, $testMeta, $uri);
    }
    await world.init();
    await use(world);
    await world.destroy();
  },
  Given: ({
    $bddWorld
  }, use) => use(new _StepInvoker.StepInvoker($bddWorld, 'Given').invoke),
  When: ({
    $bddWorld
  }, use) => use(new _StepInvoker.StepInvoker($bddWorld, 'When').invoke),
  Then: ({
    $bddWorld
  }, use) => use(new _StepInvoker.StepInvoker($bddWorld, 'Then').invoke),
  And: ({
    $bddWorld
  }, use) => use(new _StepInvoker.StepInvoker($bddWorld, 'And').invoke),
  But: ({
    $bddWorld
  }, use) => use(new _StepInvoker.StepInvoker($bddWorld, 'But').invoke),
  // init $testMetaMap with empty object, will be overwritten in each test file
  $testMetaMap: ({}, use) => use({}),
  // concrete test meta
  $testMeta: ({
    $testMetaMap
  }, use, testInfo) => use((0, _testMeta.getTestMeta)($testMetaMap, testInfo)),
  // concrete test tags
  $tags: ({
    $testMeta
  }, use) => use($testMeta.tags || []),
  // init $test with base test, but it will be overwritten in test file
  $test: ({}, use) => use(_test.test),
  // feature file uri, relative to configDir, will be overwritten in test file
  $uri: ({}, use) => use(''),
  // can be owerwritten in test file if there are scenario hooks
  $scenarioHookFixtures: ({}, use) => use({}),
  $before: [
  // Unused dependencies are important:
  // 1. $beforeAll / $afterAll: in pw < 1.39 worker-scoped auto-fixtures were called after test-scoped
  // 2. $after: to call after hooks in case of errors in before hooks
  async ({
    $scenarioHookFixtures,
    $bddWorld,
    $tags,
    $beforeAll,
    $afterAll,
    $after
  }, use, $testInfo) => {
    await (0, _scenario.runScenarioHooks)('before', {
      $bddWorld,
      $tags,
      $testInfo,
      ...$scenarioHookFixtures
    });
    await use();
  }, {
    auto: true
  }],
  $after: [async ({
    $scenarioHookFixtures,
    $bddWorld,
    $tags
  }, use, $testInfo) => {
    await use();
    await (0, _scenario.runScenarioHooks)('after', {
      $bddWorld,
      $tags,
      $testInfo,
      ...$scenarioHookFixtures
    });
  }, {
    auto: true
  }],
  // can be owerwritten in test file if there are worker hooks
  $workerHookFixtures: [({}, use) => use({}), {
    scope: 'worker'
  }],
  $beforeAll: [
  // Important unused dependencies:
  // 1. $afterAll: in pw < 1.39 worker-scoped auto-fixtures are called in incorrect order
  // 2. $cucumber: to load hooks before this fixtures
  async ({
    $workerHookFixtures,
    $cucumber
  }, use, $workerInfo) => {
    await (0, _worker.runWorkerHooks)('beforeAll', {
      $workerInfo,
      ...$workerHookFixtures
    });
    await use();
  }, {
    auto: true,
    scope: 'worker'
  }],
  $afterAll: [async ({
    $workerHookFixtures
  }, use, $workerInfo) => {
    await use();
    await (0, _worker.runWorkerHooks)('afterAll', {
      $workerInfo,
      ...$workerHookFixtures
    });
  }, {
    auto: true,
    scope: 'worker'
  }]
});
const BDD_AUTO_INJECT_FIXTURES = ['$testInfo', '$test', '$tags'];
function isBddAutoInjectFixture(name) {
  return BDD_AUTO_INJECT_FIXTURES.includes(name);
}