"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBdd = createBdd;
exports.hasCustomTest = void 0;
var _bddFixtures = require("../run/bddFixtures");
var _testTypeImpl = require("../playwright/testTypeImpl");
var _defineStep = require("./defineStep");
var _exit = require("../utils/exit");
var _scenario = require("../hooks/scenario");
var _worker = require("../hooks/worker");
/**
 * Stuff related to writing steps in Playwright-style.
 */

// Global flag showing that custom test was passed.
// Used when checking 'importTestFrom' config option.
// todo: https://github.com/vitalets/playwright-bdd/issues/46
let hasCustomTest = exports.hasCustomTest = false;
function createBdd(customTest) {
  if (!hasCustomTest) {
    exports.hasCustomTest = hasCustomTest = isCustomTest(customTest);
  }
  const Given = defineStepCtor('Given', hasCustomTest);
  const When = defineStepCtor('When', hasCustomTest);
  const Then = defineStepCtor('Then', hasCustomTest);
  const Step = defineStepCtor('Unknown', hasCustomTest);
  const Before = (0, _scenario.scenarioHookFactory)('before');
  const After = (0, _scenario.scenarioHookFactory)('after');
  const BeforeAll = (0, _worker.workerHookFactory)('beforeAll');
  const AfterAll = (0, _worker.workerHookFactory)('afterAll');
  return {
    Given,
    When,
    Then,
    Step,
    Before,
    After,
    BeforeAll,
    AfterAll
  };
}
function defineStepCtor(keyword, hasCustomTest) {
  return (pattern, fn) => {
    (0, _defineStep.defineStep)({
      keyword,
      pattern,
      fn,
      hasCustomTest
    });
  };
}
function isCustomTest(customTest) {
  if (!customTest || customTest === _bddFixtures.test) {
    return false;
  }
  assertTestHasBddFixtures(customTest);
  return true;
}
function assertTestHasBddFixtures(customTest) {
  if (!(0, _testTypeImpl.isTestContainsSubtest)(customTest, _bddFixtures.test)) {
    (0, _exit.exit)(`createBdd() should use 'test' extended from "playwright-bdd"`);
  }
}