"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildCucumberStepCode = buildCucumberStepCode;
exports.defineStep = defineStep;
exports.getStepCode = getStepCode;
var _cucumber = require("@cucumber/cucumber");
var _exit = require("../utils/exit");
/**
 * Defines step by config.
 * Calls cucumber's Given(), When(), Then() under the hood.
 */
function defineStep(stepConfig) {
  const {
    keyword,
    pattern
  } = stepConfig;
  const cucumberDefineStepFn = getCucumberDefineStepFn(keyword);
  const code = buildCucumberStepCode(stepConfig);
  try {
    cucumberDefineStepFn(pattern, code);
  } catch (e) {
    // todo: detect that this is import from test file
    // and skip/delay registering cucumber steps until cucumber is loaded
    const isMissingCucumber = /Cucumber that isn't running/i.test(e.message);
    if (isMissingCucumber) {
      (0, _exit.exit)(`Option "importTestFrom" should point to a separate file without step definitions`, `(e.g. without calls of Given, When, Then)`);
    } else {
      throw e;
    }
  }
}
function buildCucumberStepCode(stepConfig) {
  const code = function (...args) {
    // build the first argument (fixtures) for step fn
    const fixturesArg = Object.assign({}, this.$internal.currentStepFixtures, {
      $testInfo: this.testInfo,
      $test: this.test,
      $tags: this.tags
    });
    return stepConfig.fn.call(this, fixturesArg, ...args);
  };
  code.stepConfig = stepConfig;
  return code;
}
function getStepCode(stepDefinition) {
  return stepDefinition.code;
}
function getCucumberDefineStepFn(keyword) {
  switch (keyword) {
    case 'Given':
      return _cucumber.Given;
    case 'When':
      return _cucumber.When;
    case 'Then':
      return _cucumber.Then;
    default:
      return _cucumber.defineStep;
  }
}