"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.callWithTimeout = callWithTimeout;
exports.extractTemplateParams = extractTemplateParams;
exports.getPackageVersion = getPackageVersion;
exports.getSymbolByName = getSymbolByName;
exports.omit = omit;
exports.removeDuplicates = removeDuplicates;
exports.resolvePackageRoot = resolvePackageRoot;
exports.stringifyLocation = stringifyLocation;
exports.template = template;
exports.toPosixPath = toPosixPath;
var _fs = _interopRequireDefault(require("fs"));
var _path = _interopRequireDefault(require("path"));
var _util = require("util");
const setTimeoutPromise = (0, _util.promisify)(setTimeout);
/**
 * Returns Symbol by name.
 * See: https://stackoverflow.com/questions/50453640/how-can-i-get-the-value-of-a-symbol-property
 */
function getSymbolByName(target, name) {
  const ownKeys = Reflect.ownKeys(target);
  const symbol = ownKeys.find(key => key.toString() === `Symbol(${name})`);
  if (!symbol) {
    throw new Error(`Symbol "${name}" not found in target. ownKeys: ${ownKeys}`);
  }
  return symbol;
}
/**
 * Inserts params into template.
 * Params defined as <param>.
 */
function template(t, params = {}) {
  return t.replace(/<(.+?)>/g, (match, key) => {
    return params[key] !== undefined ? String(params[key]) : match;
  });
}
/**
 * Extracts all template params from string.
 * Params defined as <param>.
 */
function extractTemplateParams(t) {
  return [...t.matchAll(/<(.+?)>/g)].map(m => m[1]);
}
function removeDuplicates(arr) {
  return [...new Set(arr)];
}
function resolvePackageRoot(packageName) {
  const packageJsonPath = require.resolve(`${packageName}/package.json`);
  return _path.default.dirname(packageJsonPath);
}
function getPackageVersion(packageName) {
  const packageRoot = resolvePackageRoot(packageName);
  const packageJsonPath = _path.default.join(packageRoot, 'package.json');
  const packageJson = JSON.parse(_fs.default.readFileSync(packageJsonPath, 'utf8'));
  return packageJson.version || '';
}
async function callWithTimeout(fn, timeout, timeoutMsg) {
  if (!timeout) {
    return fn();
  }
  const ac = new AbortController();
  return Promise.race([fn(), setTimeoutPromise(timeout, null, {
    ref: false,
    signal: ac.signal
  }).then(() => {
    throw new Error(timeoutMsg || `Function timeout (${timeout} ms)`);
  })]).finally(() => ac.abort());
}
function stringifyLocation({
  line,
  column
}) {
  return `${line}:${column}`;
}
function omit(obj, key) {
  const res = {
    ...obj
  };
  delete res[key];
  return res;
}
/**
 * Returns path with "/" separator on all platforms.
 * See: https://stackoverflow.com/questions/53799385/how-can-i-convert-a-windows-path-to-posix-path-using-node-path
 */
function toPosixPath(somePath) {
  return somePath.split(_path.default.sep).join(_path.default.posix.sep);
}