/* eslint-disable no-console */
import { test as setup, expect } from '@zohodesk/testinglibrary';
import path from 'path';
import { existsSync, mkdirSync, readFileSync, writeFileSync } from 'fs';
import { getAuthFileDirectory } from '../../core/playwright';
import { Logger } from '../../utils/logger';

const userdata = require('./authUsers.json');

const authContent = { cookies: [] };

const LOGIN_ERR_MESSAGE = 'Need go be logged in';
// const AUTH_ERR_MESSAGE = `Founded Path - ${path.resolve(process.cwd(),'uat','playwright','.auth')} \n Find if file is Properly Created. Cookies Cannot Be Read .. `

function convertCookiesToParse(cookies, authFilePath) {
  try {
    return JSON.parse(cookies);
  } catch (err) {
    Logger.error(err);
    throw new Error(
      ` Error while parsing cookies ${err} \n${path.resolve(
        process.cwd(),
        authFilePath
      )} File is Empty`
    );
    // process.exit()
  }
}
const authDirectory = getAuthFileDirectory(); //path.resolve(process.cwd(), 'uat', 'playwright', '.auth');
if (!existsSync(authDirectory)) {
  console.log('Creating auth directory for the first time setup...');
  mkdirSync(authDirectory, { recursive: true });
}

userdata.forEach(data => {
  const authFile = path.resolve(path.join(authDirectory, `${data.filename}`));
  if (!existsSync(authFile)) {
    console.log('creating auth file..');
    writeFileSync(authFile, JSON.stringify(authContent, null, 2));
  }
  setup(data.description, async ({ page }) => {
    try {
      const cookies = readFileSync(authFile);
      const parsedCookies = convertCookiesToParse(cookies, authFile);
      await page
        .context()
        .addCookies(
          parsedCookies.cookies === undefined ? [] : parsedCookies.cookies
        );
      await page.goto(page.getBaseUrl());
      await page.waitForLoadState();
      if (await page.url().includes(process.env.domain)) {
        await page.waitForSelector(data.locator);
      } else {
        throw new Error(LOGIN_ERR_MESSAGE);
      }
    } catch (err) {
      if (err.message === LOGIN_ERR_MESSAGE) {
        await expect(page.locator('.load-bg')).toBeHidden();
        await page.locator('#login_id').type(data.useremail);
        await page.locator('#nextbtn').click();
        await page.locator('#password').type(data.password);
        await page.locator('#nextbtn').click();

        await page.waitForLoadState('networkidle');

        await page.waitForSelector(data.locator);

        await page.context().storageState({ path: authFile });
      }
    }
  });
});
